@@ -1,11 +1,12 @@
 #pragma once
 #include <halp/inline.hpp>
+#include <halp/modules.hpp>
 #include <halp/polyfill.hpp>
 #include <halp/static_string.hpp>
 
 #include <string_view>
 #include <type_traits>
-
+HALP_MODULE_EXPORT
 namespace halp
 {
 /// Basic value port
