@@ -5,6 +5,9 @@
 // (See accompanying file LICENSE or copy at http://www.boost.org/LICENSE_1_0.txt)
 //
 
+#include <boost/asio/use_awaitable.hpp>
+#ifdef BOOST_ASIO_HAS_CO_AWAIT
+
 //[publisher
 #include <chrono>
 #include <cstdlib>
@@ -13,22 +16,35 @@
 
 #include <boost/asio/as_tuple.hpp>
 #include <boost/asio/co_spawn.hpp>
+#include <boost/asio/deferred.hpp>
 #include <boost/asio/detached.hpp>
 #include <boost/asio/io_context.hpp>
 #include <boost/asio/signal_set.hpp>
 #include <boost/asio/steady_timer.hpp>
-#include <boost/asio/use_awaitable.hpp>
 
 #include <boost/asio/ip/tcp.hpp>
 
-#include <async_mqtt5.hpp>
+#include <async_mqtt5/logger.hpp>
+#include <async_mqtt5/mqtt_client.hpp>
+#include <async_mqtt5/reason_codes.hpp>
+#include <async_mqtt5/types.hpp>
 
-#ifdef BOOST_ASIO_HAS_CO_AWAIT
+struct config {
+	std::string brokers = "broker.hivemq.com";
+	uint16_t port = 1883;
+	std::string client_id = "async_mqtt5_tester";
+};
 
 // Modified completion token that will prevent co_await from throwing exceptions.
-constexpr auto use_nothrow_awaitable = boost::asio::as_tuple(boost::asio::use_awaitable);
+constexpr auto use_nothrow_awaitable = boost::asio::as_tuple(boost::asio::deferred);
 
-using client_type = async_mqtt5::mqtt_client<boost::asio::ip::tcp::socket>;
+// client_type with logging enabled
+using client_type = async_mqtt5::mqtt_client<
+	boost::asio::ip::tcp::socket, std::monostate /* TlsContext */, async_mqtt5::logger
+>;
+
+// client_type without logging
+//using client_type = async_mqtt5::mqtt_client<boost::asio::ip::tcp::socket>;
 
 int next_sensor_reading() {
 	srand(static_cast<unsigned int>(std::time(0)));
@@ -36,12 +52,13 @@ int next_sensor_reading() {
 }
 
 boost::asio::awaitable<void> publish_sensor_readings(
-	client_type& client, boost::asio::steady_timer& timer
+	const config& cfg, client_type& client, boost::asio::steady_timer& timer
 ) {
 	// Configure the Client.
 	// It is mandatory to call brokers() and async_run() to configure the Brokers to connect to and start the Client.
-	client.brokers("<your-mqtt-broker>", 1883) // Broker that we want to connect to. 1883 is the default TCP port.
-		.async_run(boost::asio::detached); // Start the client.
+	client.brokers(cfg.brokers, cfg.port) // Broker that we want to connect to.
+		.credentials(cfg.client_id) // Set the Client Identifier. (optional)
+		.async_run(boost::asio::detached); // Start the Client.
 
 	for (;;) {
 		// Get the next sensor reading.
@@ -49,7 +66,7 @@ boost::asio::awaitable<void> publish_sensor_readings(
 
 		// Publish the sensor reading with QoS 1.
 		auto&& [ec, rc, props] = co_await client.async_publish<async_mqtt5::qos_e::at_least_once>(
-			"<your-mqtt-topic>", reading,
+			"async-mqtt5/test" /* topic */, reading /* payload */,
 			async_mqtt5::retain_e::no, async_mqtt5::publish_props {}, use_nothrow_awaitable
 		);		
 		// An error can occur as a result of:
@@ -78,12 +95,20 @@ boost::asio::awaitable<void> publish_sensor_readings(
 	co_return;
 }
 
-int main() {
+int main(int argc, char** argv) {
+	config cfg;
+
+	if (argc == 4) {
+		cfg.brokers = argv[1];
+		cfg.port = uint16_t(std::stoi(argv[2]));
+		cfg.client_id = argv[3];
+	}
+
 	// Initialise execution context.
 	boost::asio::io_context ioc;
 
 	// Initialise the Client to connect to the Broker over TCP.
-	client_type client(ioc);
+	client_type client(ioc, {} /* tls_context */, async_mqtt5::logger(async_mqtt5::log_level::info));
 
 	// Initialise the timer.
 	boost::asio::steady_timer timer(ioc);
@@ -98,12 +123,27 @@ int main() {
 	});
 
 	// Spawn the coroutine.
-	co_spawn(ioc.get_executor(), publish_sensor_readings(client, timer), boost::asio::detached);
+	co_spawn(
+		ioc.get_executor(),
+		publish_sensor_readings(cfg, client, timer),
+		[](std::exception_ptr e) {
+			if (e)
+				std::rethrow_exception(e);
+		}
+	);
 
 	// Start the execution.
 	ioc.run();
 }
 
-#endif
-
 //]
+
+#else
+
+#include <iostream>
+
+int main() {
+	std::cout << "This example requires C++20 standard to compile and run" << std::endl;
+}
+
+#endif
