@@ -27,23 +27,20 @@
 #include <boost/asio/write.hpp>
 #include <boost/asio/ip/tcp.hpp>
 
-#include <boost/beast/http/field.hpp>
-#include <boost/beast/websocket/rfc6455.hpp>
-#include <boost/beast/websocket/stream_base.hpp>
-
 #include <async_mqtt5/error.hpp>
 #include <async_mqtt5/reason_codes.hpp>
 
 #include <async_mqtt5/detail/async_traits.hpp>
 #include <async_mqtt5/detail/control_packet.hpp>
 #include <async_mqtt5/detail/internal_types.hpp>
+#include <async_mqtt5/detail/log_invoke.hpp>
 
 #include <async_mqtt5/impl/codecs/message_decoders.hpp>
 #include <async_mqtt5/impl/codecs/message_encoders.hpp>
 
 namespace async_mqtt5::detail {
 
-template <typename Stream>
+template <typename Stream, typename LoggerType>
 class connect_op {
 	static constexpr size_t min_packet_sz = 5;
 
@@ -60,6 +57,7 @@ class connect_op {
 
 	Stream& _stream;
 	mqtt_ctx& _ctx;
+	log_invoke<LoggerType>& _log;
 
 	using handler_type = asio::any_completion_handler<void (error_code)>;
 	handler_type _handler;
@@ -68,14 +66,15 @@ class connect_op {
 	asio::cancellation_state _cancellation_state;
 
 	using endpoint = asio::ip::tcp::endpoint;
-	using epoints = asio::ip::tcp::resolver::results_type;
 
 public:
 	template <typename Handler>
 	connect_op(
-		Stream& stream, Handler&& handler, mqtt_ctx& ctx
+		Stream& stream, mqtt_ctx& ctx,
+		log_invoke<LoggerType>& log,
+		Handler&& handler
 	) :
-		_stream(stream), _ctx(ctx),
+		_stream(stream), _ctx(ctx), _log(log),
 		_handler(std::forward<Handler>(handler)),
 		_cancellation_state(
 			asio::get_associated_cancellation_slot(_handler),
@@ -106,14 +105,12 @@ public:
 		return asio::get_associated_executor(_handler);
 	}
 
-	void perform(
-		const epoints& eps, authority_path ap
-	) {
+	void perform(const endpoint& ep, authority_path ap) {
 		lowest_layer(_stream).async_connect(
-			*std::begin(eps),
+			ep,
 			asio::append(
 				asio::prepend(std::move(*this), on_connect {}),
-				*std::begin(eps), std::move(ap)
+				ep, std::move(ap)
 			)
 		);
 	}
@@ -124,6 +121,7 @@ public:
 		if (is_cancelled())
 			return complete(asio::error::operation_aborted);
 
+		_log.at_tcp_connect(ec, ep);
 		if (ec)
 			return complete(ec);
 
@@ -141,10 +139,10 @@ public:
 			);
 		}
 		else if constexpr (
-			has_tls_handshake<typename next_layer_type<Stream>::type>
+			has_tls_handshake<next_layer_type<Stream>>
 		) {
 			_stream.next_layer().async_handshake(
-				tls_handshake_type<typename next_layer_type<Stream>::type>::client,
+				tls_handshake_type<next_layer_type<Stream>>::client,
 				asio::append(
 					asio::prepend(std::move(*this), on_tls_handshake {}),
 					std::move(ep), std::move(ap)
@@ -156,53 +154,39 @@ public:
 	}
 
 	void operator()(
-		on_tls_handshake, error_code ec,
-		endpoint ep, authority_path ap
+		on_tls_handshake, error_code ec, endpoint ep, authority_path ap
 	) {
 		if (is_cancelled())
 			return complete(asio::error::operation_aborted);
 
+		_log.at_tls_handshake(ec, ep);
 		if (ec)
 			return complete(ec);
 
 		do_ws_handshake(std::move(ep), std::move(ap));
 	}
 
-	void do_ws_handshake(endpoint, authority_path ap) {
-		if constexpr (has_ws_handshake<Stream>) {
-			using namespace boost::beast;
-
-			// We'll need to turn off read timeouts on the underlying stream
-			// because the websocket stream has its own timeout system.
-
-			// Set suggested timeout settings for the websocket
-			_stream.set_option(
-				websocket::stream_base::timeout::suggested(role_type::client)
+	void do_ws_handshake(endpoint ep, authority_path ap) {
+		if constexpr (has_ws_handshake<Stream>)
+			// If you get a compilation error here,
+			// it might be because of a missing <async_mqtt5/websocket.hpp> include
+			ws_handshake_traits<Stream>::async_handshake(
+				_stream, std::move(ap),
+				asio::append(
+					asio::prepend(std::move(*this), on_ws_handshake {}), ep
+				)
 			);
-
-			_stream.binary(true);
-
-			// Set a decorator to change the User-Agent of the handshake
-			_stream.set_option(websocket::stream_base::decorator(
-				[](websocket::request_type& req) {
-					req.set(http::field::sec_websocket_protocol, "mqtt");
-					req.set(http::field::user_agent, "boost.mqtt");
-				})
-			);
-
-			_stream.async_handshake(
-				ap.host + ':' + ap.port, ap.path,
-				asio::prepend(std::move(*this), on_ws_handshake {})
-			);
-		}
 		else
-			(*this)(on_ws_handshake {}, error_code {});
+			(*this)(on_ws_handshake {}, error_code {}, ep);
 	}
 
-	void operator()(on_ws_handshake, error_code ec) {
+	void operator()(on_ws_handshake, error_code ec, endpoint ep) {
 		if (is_cancelled())
 			return complete(asio::error::operation_aborted);
 
+		if constexpr (has_ws_handshake<Stream>)
+			_log.at_ws_handshake(ec, ep);
+
 		if (ec)
 			return complete(ec);
 
@@ -346,6 +330,7 @@ public:
 		if (!rc.has_value()) // reason code not allowed in CONNACK
 			return complete(client::error::malformed_packet);
 
+		_log.at_connack(*rc, session_present, ca_props);
 		if (*rc)
 			return complete(asio::error::try_again);
 
@@ -404,7 +389,7 @@ public:
 		detail::async_write(
 			_stream, asio::buffer(wire_data),
 			asio::consign(
-				asio::prepend(std::move(*this), on_send_auth{}),
+				asio::prepend(std::move(*this), on_send_auth {}),
 				std::move(packet)
 			)
 		);
