@@ -2,6 +2,8 @@
 #include <libremidi/backends/dummy.hpp>
 #include <libremidi/backends/keyboard/midi_in.hpp>
 
+#include <string_view>
+
 namespace libremidi
 {
 struct kbd_backend
@@ -13,8 +15,8 @@ struct kbd_backend
   using midi_out_configuration = dummy_configuration;
   using midi_observer_configuration = dummy_configuration;
   static const constexpr auto API = libremidi::API::KEYBOARD;
-  static const constexpr auto name = "keyboard";
-  static const constexpr auto display_name = "Computer keyboard";
+  static const constexpr std::string_view name = "keyboard";
+  static const constexpr std::string_view display_name = "Computer keyboard";
 
   static inline bool available() noexcept { return true; }
 };
