@@ -47,8 +47,8 @@ using namespace ::Microsoft::Windows::Devices::Midi2::Initialization;
 
 inline bool ichar_equals(char a, char b)
 {
-  return std::tolower(static_cast<unsigned char>(a)) ==
-         std::tolower(static_cast<unsigned char>(b));
+  return std::tolower(static_cast<unsigned char>(a))
+         == std::tolower(static_cast<unsigned char>(b));
 }
 
 inline bool iequals(std::string_view lhs, std::string_view rhs)
