@@ -5,6 +5,7 @@
 #include <libremidi/backends/alsa_raw_ump/config.hpp>
 #include <libremidi/backends/alsa_seq/config.hpp>
 #include <libremidi/backends/alsa_seq_ump/config.hpp>
+#include <libremidi/backends/android/config.hpp>
 #include <libremidi/backends/coremidi/config.hpp>
 #include <libremidi/backends/coremidi_ump/config.hpp>
 #include <libremidi/backends/emscripten/config.hpp>
@@ -37,7 +38,8 @@ using input_api_configuration = std::variant<
     kbd_input_configuration, libremidi::net::dgram_input_configuration,
     libremidi::net_ump::dgram_input_configuration, pipewire_input_configuration,
     winmidi::input_configuration, winmm_input_configuration, winuwp_input_configuration,
-    jack_ump::input_configuration, pipewire_ump::input_configuration, libremidi::API>;
+    jack_ump::input_configuration, pipewire_ump::input_configuration, android::input_configuration,
+    libremidi::API>;
 
 using output_api_configuration = std::variant<
     unspecified_configuration, dummy_configuration, alsa_raw_output_configuration,
@@ -47,7 +49,7 @@ using output_api_configuration = std::variant<
     libremidi::net::dgram_output_configuration, libremidi::net_ump::dgram_output_configuration,
     pipewire_output_configuration, winmidi::output_configuration, winmm_output_configuration,
     winuwp_output_configuration, jack_ump::output_configuration,
-    pipewire_ump::output_configuration, libremidi::API>;
+    pipewire_ump::output_configuration, android::output_configuration, libremidi::API>;
 
 using observer_api_configuration = std::variant<
     unspecified_configuration, dummy_configuration, alsa_raw_observer_configuration,
@@ -57,7 +59,8 @@ using observer_api_configuration = std::variant<
     jack_observer_configuration, libremidi::net::dgram_observer_configuration,
     libremidi::net_ump::dgram_observer_configuration, pipewire_observer_configuration,
     winmidi::observer_configuration, winmm_observer_configuration, winuwp_observer_configuration,
-    jack_ump::observer_configuration, pipewire_ump::observer_configuration, libremidi::API>;
+    jack_ump::observer_configuration, pipewire_ump::observer_configuration,
+    android::observer_configuration, libremidi::API>;
 
 LIBREMIDI_EXPORT
 libremidi::API midi_api(const input_api_configuration& conf);
