@@ -27,10 +27,7 @@ public:
   {
     return std::errc::function_not_supported;
   }
-  virtual stdx::error set_port_name(std::string_view)
-  {
-    return std::errc::function_not_supported;
-  }
+  virtual stdx::error set_port_name(std::string_view) { return std::errc::function_not_supported; }
 
   virtual stdx::error close_port() = 0;
 
