@@ -1,6 +1,9 @@
 #include "priorized_policy.hpp"
 
+#include <ossia/dataflow/execution/to_state_element.hpp>
+#include <ossia/detail/flat_map.hpp>
 #include <ossia/editor/state/detail/state_flatten_visitor.hpp>
+#include <ossia/network/base/node_attributes.hpp>
 
 namespace ossia
 {
