@@ -15,20 +15,21 @@
 #elif defined(__x86_64__) || defined(_M_X64)
 #include <immintrin.h>
 #define ossia_rwlock_pause() _mm_pause()
-#elif defined(_M_ARM64)
-#include <intrin.h>
-#define ossia_rwlock_pause() YieldProcessor()
 #elif defined(__i386__)
 #define ossia_rwlock_pause() __asm__ __volatile__("rep; nop")
 #elif defined(__ia64__)
 #define ossia_rwlock_pause() __asm__ __volatile__("hint @pause")
+#elif defined(__aarch64__)
+#define ossia_rwlock_pause() __asm__ __volatile__("dmb ishst\n\tyield" ::: "memory")
 #elif defined(__arm__)
 #define ossia_rwlock_pause() __asm__ __volatile__("yield")
 #elif defined(__sparc) || defined(__sparc__)
 #define ossia_rwlock_pause() __asm__ __volatile__("pause")
 #elif defined(__ppc__) || defined(_ARCH_PPC) || defined(_ARCH_PWR) \
     || defined(_ARCH_PWR2) || defined(_POWER)
-#define ossia_rwlock_pause() __asm__ volatile("or 27,27,27")
+#define ossia_rwlock_pause() __asm__ __volatile__("or 27,27,27")
+#elif defined(#elif defined(__riscv)
+#define ossia_rwlock_pause() __asm__ __volatile__("pause"))
 #elif defined(_MSC_VER)
 #include <windows.h>
 #define ossia_rwlock_pause() YieldProcessor()
