@@ -6,13 +6,19 @@
     the main way in for Mac OS and, with Michael Casey's help, also into
     ASIO in Windows.
 
-    For the polling scheduler, we call portaudio in callback mode and manage
-    our own FIFO, so we can offer Pd "blocking" I/O calls. We can choose
-    between two methods for waiting on the I/O to complete, either correct
-    thread synchronization (by defining THREADSIGNAL) or just sleeping and polling.
+    Both blocking and non-blocking call styles are supported.  If non-blocking
+    is requested, either we call portaudio in non-blocking mode, or else we
+    call portaudio in callback mode and manage our own FIFO se we can offer
+    Pd "blocking" I/O calls.  To do the latter we define FAKEBLOCKING; this
+    works better in MACOSX (gets 40 msec lower latency!) and might also in
+    Windows.  If FAKEBLOCKING is defined we can choose between two methods
+    for waiting on the (presumably other-thread) I/O to complete, either
+    correct thread synchronization (by defining THREADSIGNAL) or just sleeping
+    and polling; the latter seems to work better so far.
+*/
 
-    For the callback scheduler, we call portaudio in callback mode and simply
-    provide a callback function that ticks the scheduler, polls the GUI, etc.
+/* dolist...
+    switch to usleep in s_inter.c
 */
 
 #include "m_pd.h"
@@ -28,13 +34,16 @@
 #endif
 
 #include "m_private_utils.h"
-#include "s_audio_paring.h"
 
 #ifndef _WIN32          /* for the "dup2" workaround -- do we still need it? */
 #include <unistd.h>
 #endif
 
-/* enable proper thread synchronization instead of polling */
+#if 1
+#define FAKEBLOCKING
+#endif
+
+/* enable thread signaling instead of polling */
 #if 1
 #define THREADSIGNAL
 #endif
@@ -51,8 +60,11 @@ static t_sample *pa_soundin, *pa_soundout;
 static t_audiocallback pa_callback;
 
 static int pa_started;
-static volatile int pa_dio_error;
+static int pa_nbuffers;
+static int pa_dio_error;
 
+#ifdef FAKEBLOCKING
+#include "s_audio_paring.h"
 static PA_VOLATILE char *pa_outbuf;
 static PA_VOLATILE sys_ringbuf pa_outring;
 static PA_VOLATILE char *pa_inbuf;
@@ -66,6 +78,7 @@ t_semaphore *pa_sem;
 #define POLL_TIMEOUT 2.0
 #endif
 static double pa_lastdactime;
+#endif  /* FAKEBLOCKING */
 
 static void pa_init(void)        /* Initialize PortAudio  */
 {
@@ -146,6 +159,7 @@ static int pa_lowlevel_callback(const void *inputBuffer,
     return 0;
 }
 
+#ifdef FAKEBLOCKING
     /* callback for "non-callback" case in which we actually open portaudio
     in callback mode but fake "blocking mode". We communicate with the main
     thread via two FIFOs: the audio input buffer is copied to our input FIFO
@@ -209,9 +223,10 @@ static int pa_fifo_callback(const void *inputBuffer,
 #endif
     return 0;
 }
+#endif /* FAKEBLOCKING */
 
 PaError pa_open_callback(double samplerate, int inchannels, int outchannels,
-    int framesperbuf, int indeviceno, int outdeviceno, PaStreamCallback *callbackfn)
+    int framesperbuf, int nbuffers, int indeviceno, int outdeviceno, PaStreamCallback *callbackfn)
 {
     long bytesPerSample;
     PaError err;
@@ -228,15 +243,21 @@ PaError pa_open_callback(double samplerate, int inchannels, int outchannels,
     instreamparams.channelCount = inchannels;
     instreamparams.sampleFormat = paFloat32;
     instreamparams.hostApiSpecificStreamInfo = 0;
-    instreamparams.suggestedLatency = 0;
-    if (inchannels > 0 && indeviceno >= 0)
-        p_instreamparams = &instreamparams;
 
     outstreamparams.device = outdeviceno;
     outstreamparams.channelCount = outchannels;
     outstreamparams.sampleFormat = paFloat32;
     outstreamparams.hostApiSpecificStreamInfo = 0;
-    outstreamparams.suggestedLatency = 0;
+
+#ifdef FAKEBLOCKING
+    instreamparams.suggestedLatency = outstreamparams.suggestedLatency = 0;
+#else
+    instreamparams.suggestedLatency = outstreamparams.suggestedLatency =
+        nbuffers * framesperbuf / samplerate;
+#endif /* FAKEBLOCKING */
+
+    if (inchannels > 0 && indeviceno >= 0)
+        p_instreamparams = &instreamparams;
     if (outchannels > 0 && outdeviceno >= 0)
         p_outstreamparams = &outstreamparams;
 
@@ -311,7 +332,7 @@ PaError pa_open_callback(double samplerate, int inchannels, int outchannels,
     err = Pa_StartStream(pa_stream);
     if (err != paNoError)
     {
-        post("could not start stream; closing audio: %s",
+        post("error opening failed; closing audio stream: %s",
             Pa_GetErrorText(err));
         pa_close_audio();
         goto error;
@@ -356,12 +377,6 @@ int pa_open_audio(int inchans, int outchans, int rate, t_sample *soundin,
                 devno++;
             }
         }
-        if (pa_indev == -1)
-        {
-            inchans = 0;
-            pd_error(0, "audio input device number (%d) out of range",
-                indeviceno);
-        }
     }
 
     if (outchans > 0)
@@ -382,27 +397,24 @@ int pa_open_audio(int inchans, int outchans, int rate, t_sample *soundin,
                 devno++;
             }
         }
-        if (pa_outdev == -1)
-        {
-            outchans = 0;
-            pd_error(0, "audio output device number (%d) out of range",
-                outdeviceno);
-        }
     }
 
+    if (inchans > 0 && pa_indev == -1)
+        inchans = 0;
+    if (outchans > 0 && pa_outdev == -1)
+        outchans = 0;
+
     logpost(NULL, PD_VERBOSE, "input device %d, channels %d", pa_indev, inchans);
     logpost(NULL, PD_VERBOSE, "output device %d, channels %d", pa_outdev, outchans);
     logpost(NULL, PD_VERBOSE, "framesperbuf %d, nbufs %d", framesperbuf, nbuffers);
     logpost(NULL, PD_VERBOSE, "rate %d", rate);
 
-    if (!inchans && !outchans)
-        return (1);
-
     pa_inchans = STUFF->st_inchannels = inchans;
     pa_outchans = STUFF->st_outchannels = outchans;
     pa_soundin = soundin;
     pa_soundout = soundout;
 
+#ifdef FAKEBLOCKING
     if (pa_inbuf)
         free((char *)pa_inbuf), pa_inbuf = 0;
     if (pa_outbuf)
@@ -411,15 +423,20 @@ int pa_open_audio(int inchans, int outchans, int rate, t_sample *soundin,
     pa_sem = sys_semaphore_create();
 #endif
     pa_lastdactime = 0;
+#endif
+
+    if (!inchans && !outchans)
+        return (0);
 
     if (callbackfn)
     {
         pa_callback = callbackfn;
         err = pa_open_callback(rate, inchans, outchans,
-            framesperbuf, pa_indev, pa_outdev, pa_lowlevel_callback);
+            framesperbuf, nbuffers, pa_indev, pa_outdev, pa_lowlevel_callback);
     }
     else
     {
+#ifdef FAKEBLOCKING
         if (pa_inchans)
         {
             pa_inbuf = malloc(nbuffers*framesperbuf*pa_inchans*sizeof(float));
@@ -434,10 +451,14 @@ int pa_open_audio(int inchans, int outchans, int rate, t_sample *soundin,
                 nbuffers*framesperbuf*pa_outchans*sizeof(float), pa_outbuf, 0);
         }
         err = pa_open_callback(rate, inchans, outchans,
-            framesperbuf, pa_indev, pa_outdev, pa_fifo_callback);
+            framesperbuf, nbuffers, pa_indev, pa_outdev, pa_fifo_callback);
+#else
+        err = pa_open_callback(rate, inchans, outchans,
+            framesperbuf, nbuffers, pa_indev, pa_outdev, 0);
+#endif
     }
     pa_started = 0;
-    pa_dio_error = 0;
+    pa_nbuffers = nbuffers;
     if (err != paNoError)
     {
         pd_error(0, "error opening audio: %s", Pa_GetErrorText(err));
@@ -456,6 +477,7 @@ void pa_close_audio(void)
         Pa_CloseStream(pa_stream);
     }
     pa_stream = 0;
+#ifdef FAKEBLOCKING
     if (pa_inbuf)
         free((char *)pa_inbuf), pa_inbuf = 0;
     if (pa_outbuf)
@@ -467,43 +489,14 @@ void pa_close_audio(void)
         pa_sem = 0;
     }
 #endif
-}
-
-void sys_do_close_audio(void);
-void sys_do_reopen_audio(void);
-
-int pa_reopen_audio(void)
-{
-    int success;
-        /* NB: unfortunately, Pa_IsStreamActive() always returns true,
-           even if the audio device has been disconnected... */
-    sys_do_close_audio();
-#ifdef __APPLE__
-        /* TODO: the portaudio coreaudio implementation doesn't handle
-           re-connection, so suggest restarting */
-    pd_error(0, "audio device not responding - closing audio");
-    pd_error(0, "you may need to save and restart pd");
-    return 0;
-#else
-        /* portaudio seems to handle this better on windows and linux */
-    pd_error(0, "trying to reopen audio device");
-
-    sys_do_reopen_audio(); /* try to reopen it */
-    success = audio_isopen();
-
-    if (success)
-        pd_error(0, "successfully reopened audio device");
-    else
-        pd_error(0, "audio device not responding - closing audio.\n"
-                    "please try to reconnect and reselect it in the settings (or toggle DSP)");
 #endif
-    return success;
 }
 
 int sched_idletask(void);
 
 int pa_send_dacs(void)
 {
+    PaError err;
     t_sample *fp;
     float *fp2, *fp3;
     float *conversionbuf;
@@ -517,6 +510,7 @@ int pa_send_dacs(void)
     conversionbuf = (float *)alloca((STUFF->st_inchannels > STUFF->st_outchannels?
         STUFF->st_inchannels:STUFF->st_outchannels) * DEFDACBLKSIZE * sizeof(float));
 
+#ifdef FAKEBLOCKING
     while (
         (sys_ringbuf_getreadavailable(&pa_inring) <
             (long)(STUFF->st_inchannels * DEFDACBLKSIZE*sizeof(t_sample))) ||
@@ -529,14 +523,19 @@ int pa_send_dacs(void)
             /* only go to sleep if there is nothing else to do. */
         if (!sys_semaphore_waitfor(pa_sem, POLL_TIMEOUT))
         {
-            pa_reopen_audio();
-            return SENDDACS_NO;
+                /* timed out -> check stream */
+            if ((err = Pa_IsStreamActive(pa_stream)) < 0)
+                goto try_reopen;
+            else /* should not really happen */
+                return SENDDACS_NO;
         }
         retval = SENDDACS_SLEPT;
 #else
-        if ((timeref - pa_lastdactime) >= POLL_TIMEOUT)
-            pa_reopen_audio();
-        return SENDDACS_NO;
+        if (((timeref - pa_lastdactime) >= POLL_TIMEOUT)
+            && ((err = Pa_IsStreamActive(&pa_stream)) < 0))
+                goto try_reopen;
+        else
+            return SENDDACS_NO;
 #endif
     }
     pa_lastdactime = timeref;
@@ -562,18 +561,69 @@ int pa_send_dacs(void)
                     k++, fp++, fp3 += STUFF->st_inchannels)
                         *fp = *fp3;
     }
-
-    if (pa_dio_error)
+#else /* FAKEBLOCKING */
+        /* write output */
+    if (STUFF->st_outchannels)
     {
-        sys_log_error(ERR_RESYNC);
-        pa_dio_error = 0;
+        if (!pa_started)
+        {
+            memset(conversionbuf, 0,
+                STUFF->st_outchannels * DEFDACBLKSIZE * sizeof(float));
+            for (j = 0; j < pa_nbuffers-1; j++)
+                Pa_WriteStream(pa_stream, conversionbuf, DEFDACBLKSIZE);
+        }
+        for (j = 0, fp = STUFF->st_soundout, fp2 = conversionbuf;
+            j < STUFF->st_outchannels; j++, fp2++)
+                for (k = 0, fp3 = fp2; k < DEFDACBLKSIZE;
+                    k++, fp++, fp3 += STUFF->st_outchannels)
+                        *fp3 = *fp;
+        if (Pa_WriteStream(pa_stream, conversionbuf, DEFDACBLKSIZE) != paNoError)
+            if ((err = Pa_IsStreamActive(&pa_stream)) < 0)
+                goto try_reopen;
     }
+        /* read input */
+    if (STUFF->st_inchannels)
+    {
+        if (Pa_ReadStream(pa_stream, conversionbuf, DEFDACBLKSIZE) != paNoError)
+            if ((err = Pa_IsStreamActive(&pa_stream)) < 0)
+                goto try_reopen;
+        for (j = 0, fp = STUFF->st_soundin, fp2 = conversionbuf;
+            j < STUFF->st_inchannels; j++, fp2++)
+                for (k = 0, fp3 = fp2; k < DEFDACBLKSIZE;
+                    k++, fp++, fp3 += STUFF->st_inchannels)
+                        *fp = *fp3;
+    }
+    if ((sys_getrealtime() - timeref) > 0.002)
+        retval = SENDDACS_SLEPT;
+#endif /* FAKEBLOCKING */
     pa_started = 1;
 
     memset(STUFF->st_soundout, 0,
         DEFDACBLKSIZE*sizeof(t_sample)*STUFF->st_outchannels);
 
     return retval;
+
+try_reopen:
+    pd_error(0, "error %d: %s", err, Pa_GetErrorText(err));
+    sys_close_audio();
+    #ifdef __APPLE__
+        /* TODO: the portaudio coreaudio implementation doesn't handle
+           re-connection, so suggest restarting */
+        pd_error(0, "audio device not responding - closing audio");
+        pd_error(0, "you may need to save and restart pd");
+    #else
+        /* portaudio seems to handle this better on windows and linux */
+        pd_error(0, "trying to reopen audio device");
+        sys_reopen_audio(); /* try to reopen it */
+        if (audio_isopen())
+            pd_error(0, "successfully reopened audio device");
+        else
+        {
+            pd_error(0, "audio device not responding - closing audio");
+            pd_error(0, "reconnect and reselect it in the settings (or toggle DSP)");
+        }
+    #endif
+    return SENDDACS_NO;
 }
 
 static char*pdi2devname(const PaDeviceInfo*pdi, char*buf, size_t bufsize) {
