@@ -28,6 +28,7 @@ Distributed under the Boost Software License, Version 1.0.
 
 static inline void TestBlockingTLSSocketHandles()
 {
+#ifndef LLFIO_EXCLUDE_NETWORKING
   namespace llfio = LLFIO_V2_NAMESPACE;
   if(llfio::tls_socket_source_registry::empty())
   {
@@ -136,8 +137,10 @@ static inline void TestBlockingTLSSocketHandles()
   auto rawserversocket = llfio::listening_byte_socket_handle::listening_byte_socket(llfio::ip::family::v4).value();
   auto rawwriter = llfio::byte_socket_handle::byte_socket(llfio::ip::family::v4).value();
   runtest(tls_socket_source->wrap(&rawserversocket).value(), tls_socket_source->wrap(&rawwriter).value());
+#endif
 }
 
+#ifndef LLFIO_EXCLUDE_NETWORKING
 struct TestNonBlockingTLSSocketHandlesRunTest
 {
   template <class F> TestNonBlockingTLSSocketHandlesRunTest(LLFIO_V2_NAMESPACE::listening_tls_socket_handle_ptr serversocket, F &&make_writer)
@@ -258,8 +261,10 @@ struct TestNonBlockingTLSSocketHandlesRunTest
     reader.first->close().value();
   }
 };
+#endif
 static inline void TestNonBlockingTLSSocketHandles()
 {
+#ifndef LLFIO_EXCLUDE_NETWORKING
   namespace llfio = LLFIO_V2_NAMESPACE;
   if(llfio::tls_socket_source_registry::empty())
   {
@@ -275,6 +280,7 @@ static inline void TestNonBlockingTLSSocketHandles()
   auto rawserversocket = llfio::listening_byte_socket_handle::multiplexable_listening_byte_socket(llfio::ip::family::v4).value();
   auto rawwriter = llfio::byte_socket_handle::multiplexable_byte_socket(llfio::ip::family::v4).value();
   TestNonBlockingTLSSocketHandlesRunTest(tls_socket_source->wrap(&rawserversocket).value(), [&] { return tls_socket_source->wrap(&rawwriter).value(); });
+#endif
 }
 
 /* This test makes the assumption that the host OS is able to validate github.com's
@@ -282,12 +288,11 @@ TLS certificate.
 */
 static inline void TestAuthenticatingTLSSocketHandles()
 {
-  static constexpr const char *test_host = "github.com";
-  static constexpr const char *get_request = R"(GET / HTTP/1.0
-Host: github.com
-
-)";
+#ifndef LLFIO_EXCLUDE_NETWORKING
+  //! [https_get]
   namespace llfio = LLFIO_V2_NAMESPACE;
+  static constexpr llfio::string_view test_host("github.com");
+  static constexpr llfio::string_view get_request("GET / HTTP/1.0\r\nHost: github.com\r\n\r\n");
   if(llfio::tls_socket_source_registry::empty())
   {
     std::cout << "\nNOTE: This platform has no TLS socket sources in its registry, skipping this test." << std::endl;
@@ -313,14 +318,15 @@ Host: github.com
   }
   // Get the front page
   std::cout << "\nThe socket which connected to " << test_host << " negotiated the cipher " << sock->algorithms_description() << std::endl;
-  auto written = sock->write({{(const llfio::byte *) get_request, strlen(get_request)}}).value();
-  BOOST_REQUIRE(written == strlen(get_request));
+  llfio::tls_socket_handle::const_buffer_type get_request_buffer(reinterpret_cast<const llfio::byte *>(get_request.data()), get_request.size());
+  auto written = sock->write({get_request_buffer}).value();
+  BOOST_REQUIRE(written == get_request.size());
   // Fetch the front page. The connection will close once all data is sent.
-  std::vector<char> buffer(4096);
+  std::vector<llfio::byte> buffer(4096);
   size_t offset = 0;
-  for(size_t readed = 0; (readed = sock->read({{(llfio::byte *) buffer.data() + offset, buffer.size() - offset}}, std::chrono::seconds(3)).value()) > 0;)
+  for(size_t nread = 0; (nread = sock->read({{buffer.data() + offset, buffer.size() - offset}}, std::chrono::seconds(3)).value()) > 0;)
   {
-    offset += readed;
+    offset += nread;
     if(buffer.size() - offset < 1024)
     {
       buffer.resize(buffer.size() + 4096);
@@ -328,10 +334,12 @@ Host: github.com
   }
   buffer.resize(offset);
   std::cout << "\nRead from " << test_host << " " << offset << " bytes. The first 1024 bytes are:\n\n"
-            << llfio::string_view(buffer.data(), offset).substr(0, 1024) << "\n"
+            << llfio::string_view(reinterpret_cast<const char *>(buffer.data()), offset).substr(0, 1024) << "\n"
             << std::endl;
   // Make sure this doesn't hang because the socket is closed
   sock->shutdown_and_close().value();
+//! [https_get]
+#endif
 }
 
 #if 0
@@ -656,6 +664,7 @@ static inline void TestCoroutinedTLSSocketHandles()
 
 static inline void TestPollingTLSSocketHandles()
 {
+#ifndef LLFIO_EXCLUDE_NETWORKING
   static constexpr size_t MAX_SOCKETS = 64;
   namespace llfio = LLFIO_V2_NAMESPACE;
   if(llfio::tls_socket_source_registry::empty())
@@ -843,6 +852,7 @@ static inline void TestPollingTLSSocketHandles()
   }
   runtest([&](size_t idx) { return tls_socket_source->wrap(&rawlisteners[idx]).value(); },
           [&](size_t idx) { return tls_socket_source->wrap(&rawwriters[idx]).value(); });
+#endif
 }
 
 KERNELTEST_TEST_KERNEL(integration, llfio, tls_socket_handle, blocking, "Tests that blocking llfio::tls_byte_socket_handle works as expected",
