@@ -1,5 +1,5 @@
 /* Proposed SG14 status_code
-(C) 2018 - 2020 Niall Douglas <http://www.nedproductions.biz/> (5 commits)
+(C) 2018 - 2024 Niall Douglas <http://www.nedproductions.biz/> (5 commits)
 File Created: Feb 2018
 
 
@@ -29,6 +29,11 @@ http://www.boost.org/LICENSE_1_0.txt)
 
 #include <cerrno>  // for error constants
 
+#if defined(_MSC_VER) && !defined(__clang__)
+#pragma warning(push)
+#pragma warning(disable : 6326)  // constant comparison
+#endif
+
 SYSTEM_ERROR2_NAMESPACE_BEGIN
 
 //! The generic error coding (POSIX)
@@ -488,4 +493,8 @@ SYSTEM_ERROR2_CONSTEXPR14 inline bool operator!=(const T &a, const status_code<D
 
 SYSTEM_ERROR2_NAMESPACE_END
 
+#if defined(_MSC_VER) && !defined(__clang__)
+#pragma warning(pop)
+#endif
+
 #endif
