@@ -6,10 +6,10 @@ sudo apt-get install wget libfuse2 desktop-file-utils
 if [[ "${CPU_ARCH}" == "aarch64" ]]; then
   export CPU_ARCH_SUFFIX="-aarch64"
 else
-  export CPU_ARCH_SUFFIX=""
+  export CPU_ARCH_SUFFIX="-x86_64"
 fi
 
-wget -nv "https://github.com/ossia/sdk/releases/download/sdk32/sdk-linux${CPU_ARCH_SUFFIX}.tar.xz"
+wget -nv "https://github.com/ossia/sdk/releases/download/sdk33/sdk-linux${CPU_ARCH_SUFFIX}.tar.xz"
 tar xaf sdk-linux${CPU_ARCH_SUFFIX}.tar.xz
 rm -rf  sdk-linux${CPU_ARCH_SUFFIX}.tar.xz
 
