@@ -3,7 +3,7 @@
 : "$SDK_DIR"
 : "$SCORE_DIR"
 
-export OSSIA_SDK="/c/ossia-sdk"
+export OSSIA_SDK="/c/ossia-sdk-x86_64"
 export DST="$SDK_DIR"
 export INCLUDE="$DST/usr/include"
 export LIB="$DST/usr/lib"
@@ -24,4 +24,5 @@ mkdir -p "$DST/usr/lib/clang/$LLVM_VER/include"
 
 cp -rf "$OSSIA_SDK/llvm-libs/lib/clang/$LLVM_VER/include" "$LIB/clang/$LLVM_VER/"
 
+source $SCRIPTDIR/cleanup-sdk-common.sh
 
