@@ -16,7 +16,7 @@ class GBAP
 {
 public:
   halp_meta(name, "GBAP")
-  halp_meta(category, "Control/Spatialization")
+  halp_meta(category, "Spatialization")
   halp_meta(c_name, "GBAP")
   halp_meta(uuid, "81DB0C30-175B-422E-8C5F-87569D50548E")
   halp_meta(
@@ -74,7 +74,7 @@ public:
     } sinkSize;
 
     halp::xy_spinboxes_f32<"Cursor Size", halp::range{.min = 0., .max = 1., .init = 0.04}> cursorSize;
-    halp::xy_pad_f32<"Position", halp::range{.min = 0., .max = 1., .init = 0.5}> pos;
+    halp::xy_spinboxes_f32<"Position", halp::range{.min = 0., .max = 1., .init = 0.5}> pos;
 
   } inputs;
 
