@@ -11,7 +11,7 @@ struct matrix::ui
 
   halp_meta(name, "Main")
   halp_meta(layout, vbox)
-  halp_meta(background, dark)
+  halp_meta(background, background_dark)
 
   halp::label title{"My First Processor"};
   halp::item<&ins::gain> gain;
