@@ -6,14 +6,14 @@
 template <>
 void DataStreamReader::read(const Protocols::BLESpecificSettings& n)
 {
-  m_stream << n.adapter << n.serial;
+  m_stream << n.adapter << n.serial << n.include_filters << n.exclude_filters;
   insertDelimiter();
 }
 
 template <>
 void DataStreamWriter::write(Protocols::BLESpecificSettings& n)
 {
-  m_stream >> n.adapter >> n.serial;
+  m_stream >> n.adapter >> n.serial >> n.include_filters >> n.exclude_filters;
   checkDelimiter();
 }
 
@@ -22,6 +22,10 @@ void JSONReader::read(const Protocols::BLESpecificSettings& n)
 {
   obj["Adapter"] = n.adapter;
   obj["Serial"] = n.serial;
+  if(!n.include_filters.isEmpty())
+    obj["Include"] = n.include_filters;
+  if(!n.exclude_filters.isEmpty())
+    obj["Exclude"] = n.exclude_filters;
 }
 
 template <>
@@ -29,4 +33,12 @@ void JSONWriter::write(Protocols::BLESpecificSettings& n)
 {
   n.adapter = obj["Adapter"].toString();
   n.serial = obj["Serial"].toString();
+  if(auto filter = obj.tryGet("Include"))
+  {
+    n.include_filters = filter->toString();
+  }
+  if(auto filter = obj.tryGet("Exclude"))
+  {
+    n.exclude_filters = filter->toString();
+  }
 }
