@@ -9,25 +9,11 @@
 #include <score/plugins/qt_interfaces/GUIApplicationPlugin_QtInterface.hpp>
 #include <score/plugins/qt_interfaces/PluginRequirements_QtInterface.hpp>
 
-#include <utility>
-#include <vector>
-
-class score_addon_onnx final
-    : public score::Plugin_QtInterface
-    , public score::FactoryInterface_QtInterface
-    , public score::CommandFactory_QtInterface
+class score_addon_onnx final : public score::Plugin_QtInterface
 {
   SCORE_PLUGIN_METADATA(1, "993b0d0f-dc5c-410a-ac3c-17edc791fde0")
 
 public:
   score_addon_onnx();
   ~score_addon_onnx() override;
-
-private:
-  std::vector<score::InterfaceBase*> factories(
-      const score::ApplicationContext& ctx,
-      const score::InterfaceKey& key) const override;
-
-  std::pair<const CommandGroupKey, CommandGeneratorMap>
-  make_commands() override;
 };
