@@ -11,7 +11,7 @@ class Roll
 {
 public:
   halp_meta(name, "Roll")
-  halp_meta(category, "Gestures")
+  halp_meta(category, "Analysis/Gestures")
   halp_meta(c_name, "puara_roll")
   halp_meta(
       description,
