@@ -11,7 +11,7 @@ struct Granola::ui
 
   halp_meta(name, "Main")
   halp_meta(layout, vbox)
-  halp_meta(background, darker)
+  halp_meta(background, background_darker)
   halp::label title{"Granulator"};
   halp::item<&ins::sound> sound;
   //halp::item<&ins::sound> win; not supported yet
@@ -19,17 +19,17 @@ struct Granola::ui
   {
     halp_meta(name, "Controls")
     halp_meta(layout, hbox)
-    halp_meta(background, dark)
+    halp_meta(background, background_dark)
     struct
     {
       halp_meta(name, "Controls")
       halp_meta(layout, vbox)
-      halp_meta(background, dark)
+      halp_meta(background, background_dark)
       struct
       {
         halp_meta(name, "Gain Controls")
         halp_meta(layout, hbox)
-        halp_meta(background, dark)
+        halp_meta(background, background_dark)
         halp::item<&ins::gain> gain;
         halp::item<&ins::gain_j> gain_j;
       } gain_box;
@@ -37,7 +37,7 @@ struct Granola::ui
       {
         halp_meta(name, "Density Controls")
         halp_meta(layout, hbox)
-        halp_meta(background, dark)
+        halp_meta(background, background_dark)
         halp::item<&ins::density> density;
         halp::item<&ins::dens_j> dens_j;
       } dens_box;
@@ -45,13 +45,13 @@ struct Granola::ui
       {
         halp_meta(name, "Pitch Controls")
         halp_meta(layout, hbox)
-        halp_meta(background, dark)
+        halp_meta(background, background_dark)
         halp::item<&ins::rate> rate;
         struct
         {
           halp_meta(name, "Pitch_extra")
           halp_meta(layout, vbox)
-          halp_meta(background, dark)
+          halp_meta(background, background_dark)
           halp::item<&ins::rate_j> rate_j;
           halp::item<&ins::reverse> reverse;
         } pitch_xtra_box;
@@ -60,7 +60,7 @@ struct Granola::ui
       {
         halp_meta(name, "Pitch_extra")
         halp_meta(layout, hbox)
-        halp_meta(background, dark)
+        halp_meta(background, background_dark)
         halp::item<&ins::playing> playing;
         halp::item<&ins::trig> trig;
       } play_box;
@@ -69,12 +69,12 @@ struct Granola::ui
     {
       halp_meta(name, "Controls")
       halp_meta(layout, vbox)
-      halp_meta(background, dark)
+      halp_meta(background, background_dark)
       struct
       {
         halp_meta(name, "Position Controls")
         halp_meta(layout, hbox)
-        halp_meta(background, dark)
+        halp_meta(background, background_dark)
         halp::item<&ins::pos> pos;
         halp::item<&ins::pos_j> pos_j;
       } pos_box;
@@ -82,7 +82,7 @@ struct Granola::ui
       {
         halp_meta(name, "Duration Controls")
         halp_meta(layout, hbox)
-        halp_meta(background, dark)
+        halp_meta(background, background_dark)
         halp::item<&ins::dur> dur;
         halp::item<&ins::dur_j> dur_j;
       } dur_box;
