@@ -1,16 +1,18 @@
 #include "GraphicsLayout.hpp"
 
+#include <score/graphics/layouts/Constants.hpp>
 #include <score/model/Skin.hpp>
 #include <score/widgets/Pixmap.hpp>
 
 #include <QPainter>
-
 namespace score
 {
 
 GraphicsLayout::GraphicsLayout(QGraphicsItem* parent)
     : score::BackgroundItem{parent}
     , m_bg{nullptr}
+    , m_margin{default_margin}
+    , m_padding{default_padding}
 {
 }
 
@@ -41,6 +43,17 @@ void GraphicsLayout::setPadding(qreal p)
   m_padding = p;
 }
 
+void GraphicsLayout::updateChildrenRects(const QList<QGraphicsItem*>& items)
+{
+  for(int i = 0; i < items.size(); i++)
+  {
+    if(auto rect = dynamic_cast<score::EmptyRectItem*>(items[i]))
+    {
+      rect->fitChildrenRect();
+    }
+  }
+}
+
 void GraphicsLayout::setMargin(qreal p)
 {
   m_margin = p;
