@@ -36,7 +36,7 @@
 #include <QTimer>
 
 #include <wobjectimpl.h>
-
+W_OBJECT_IMPL(Process::NodeItem)
 namespace Process
 {
 
@@ -68,11 +68,13 @@ NodeItem::NodeItem(
     : QGraphicsItem{parent}
     , m_model{process}
     , m_context{ctx}
+    , m_dispatcher{ctx.commandStack}
     , m_parentDuration{parentDur}
 {
   setObjectName("NodeItem");
   setAcceptedMouseButtons(Qt::LeftButton | Qt::RightButton);
   setAcceptHoverEvents(true);
+  setAcceptDrops(true);
   setFlag(ItemIsFocusable, true);
   setFlag(ItemClipsChildrenToShape, true);
   const auto& pf
@@ -94,10 +96,20 @@ NodeItem::NodeItem(
   });
 
   auto on_sizeChanged = [this] {
-    updateSize();
-    updateZoomRatio();
-    updateTitlePos();
+    m_needResize = true;
+    QTimer::singleShot(1, this, [this] {
+      if(!m_needResize)
+        return;
+      m_needResize = false;
+      updateSize();
+      updateZoomRatio();
+      updateTitlePos();
+    });
   };
+  connect(&process, &Process::ProcessModel::controlAdded, this, on_sizeChanged);
+  connect(&process, &Process::ProcessModel::controlRemoved, this, on_sizeChanged);
+  connect(&process, &Process::ProcessModel::controlOutletAdded, this, on_sizeChanged);
+  connect(&process, &Process::ProcessModel::controlOutletRemoved, this, on_sizeChanged);
   connect(&process, &Process::ProcessModel::inletsChanged, this, on_sizeChanged);
   connect(&process, &Process::ProcessModel::outletsChanged, this, on_sizeChanged);
 }
@@ -166,7 +178,17 @@ void NodeItem::createWithDecorations()
   ossia::qt::run_async(this, [this] {
     resetInlets();
     resetOutlets();
+    updateSize();
   });
+  connect(&process, &Process::ProcessModel::controlAdded, this, &NodeItem::resetInlets);
+  connect(
+      &process, &Process::ProcessModel::controlRemoved, this, &NodeItem::resetInlets);
+  connect(
+      &process, &Process::ProcessModel::controlOutletAdded, this,
+      &NodeItem::resetOutlets);
+  connect(
+      &process, &Process::ProcessModel::controlOutletRemoved, this,
+      &NodeItem::resetOutlets);
   connect(&process, &Process::ProcessModel::inletsChanged, this, &NodeItem::resetInlets);
   connect(
       &process, &Process::ProcessModel::outletsChanged, this, &NodeItem::resetOutlets);
@@ -324,7 +346,7 @@ void NodeItem::setSelected(bool s)
   update();
 }
 
-QRectF NodeItem::boundingRect() const
+QRectF NodeItem::contentRect() const noexcept
 {
   if(!m_label)
   {
@@ -352,6 +374,11 @@ QRectF NodeItem::boundingRect() const
   }
 }
 
+QRectF NodeItem::boundingRect() const
+{
+  return contentRect().adjusted(-2., -2., 2., 2.);
+}
+
 void NodeItem::createContentItem()
 {
   if(m_fx)
@@ -452,12 +479,21 @@ void NodeItem::createContentItem()
 double NodeItem::minimalContentWidth() const noexcept
 {
   if(Q_UNLIKELY(!m_label))
-    return 30.;
+  {
+    if((m_inlets.size() + m_outlets.size()) <= 1)
+      return 10.;
+    else
+      return 20.;
+  }
   else
     return std::max(75.0, TitleWithUiX0 + m_label->boundingRect().width() + 6.);
 }
 double NodeItem::minimalContentHeight() const noexcept
 {
+  if(Q_UNLIKELY(!m_label))
+    if(std::max(m_inlets.size(), m_outlets.size()) <= 1)
+      return 10.;
+
   double h = 22.;
   if(!m_inlets.empty())
     h = std::max(h, m_inlets.back()->y() + 10.);
@@ -480,13 +516,19 @@ void NodeItem::updateSize()
   //if (sz != m_contentSize || !m_fx)
   {
     prepareGeometryChange();
+    double w = std::max(minimalContentWidth(), sz.width());
+    double h = std::max(minimalContentHeight(), sz.height());
     if(m_fx)
     {
-      double w = std::max(minimalContentWidth(), sz.width());
-      double h = std::max(minimalContentHeight(), sz.height());
       m_contentSize = QSizeF{w, h};
     }
 
+    if(m_presenter)
+    {
+      m_presenter->setWidth(m_contentSize.width(), m_contentSize.width());
+      m_presenter->setHeight(m_contentSize.height());
+    }
+
     if(m_uiButton)
     {
       m_uiButton->setParentItem(nullptr);
@@ -560,15 +602,30 @@ void NodeItem::setParentDuration(TimeVal r)
 
 void NodeItem::setPlayPercentage(float f, TimeVal parent_dur)
 {
-  // Comes from the interval -> if we are looping we make a small modulo of it
-  if(m_model.loops())
+  if(m_playPercentage != f)
   {
-    auto loopDur = m_model.loopDuration().impl;
-    double playdur = f * parent_dur.impl;
-    f = std::fmod(playdur, loopDur) / loopDur;
+    // Comes from the interval -> if we are looping we make a small modulo of it
+    if(m_model.loops())
+    {
+      auto loopDur = m_model.loopDuration().impl;
+      double playdur = double(f) * parent_dur.impl;
+      f = std::fmod(playdur, loopDur) / loopDur;
+      if(m_playPercentage != f)
+      {
+        m_playPercentage = f;
+        update({12., -1., (m_contentSize.width() - 24.), 3.});
+      }
+    }
+    else
+    {
+      f = ossia::clamp(f, 0.f, 1.f);
+      if(m_playPercentage != f)
+      {
+        m_playPercentage = f;
+        update({12., -1., (m_contentSize.width() - 24.) * f + 1., 3.});
+      }
+    }
   }
-  m_playPercentage = f;
-  update({0., -1., m_contentSize.width() * f, 3.});
 }
 
 qreal NodeItem::width() const noexcept
@@ -607,7 +664,7 @@ void NodeItem::paint(
 {
   auto& style = Process::Style::instance();
   const auto& skin = style.skin;
-  const auto rect = boundingRect();
+  const auto rect = contentRect();
   //painter->fillRect(boundingRect(), Qt::red);
   // return;
 
@@ -616,7 +673,8 @@ void NodeItem::paint(
   const auto& brush = m_selected ? skin.Base2.darker
                       : m_hover  ? bset.lighter
                                  : bset.main;
-  const auto& pen = brush.pen2_solid_round_round;
+  const auto& pen = m_dropping ? skin.Warn2.main.pen3_solid_round_round
+                               : brush.pen2_solid_round_round;
 
   painter->setRenderHint(QPainter::Antialiasing, true);
 
@@ -629,10 +687,11 @@ void NodeItem::paint(
   painter->setRenderHint(QPainter::Antialiasing, false);
 
   // Exec
-  if(m_playPercentage != 0.)
+  if(m_playPercentage > 0.)
   {
     painter->setPen(style.IntervalPlayFill().main.pen1_solid_flat_miter);
-    painter->drawLine(QPointF{0., 0.}, QPointF{width() * m_playPercentage, 0.});
+    painter->drawLine(
+        QPointF{12., 0.}, QPointF{12. + (width() - 24.) * m_playPercentage, 0.});
   }
 
   // Resizing handle
@@ -701,7 +760,9 @@ selectedProcesses(const score::DocumentContext& ctx)
   ps.reserve(sel.size());
   for(auto& obj : sel)
     if(auto p = qobject_cast<Process::ProcessModel*>(obj))
+    {
       ps.push_back(p);
+    }
   return ps;
 }
 }
@@ -711,7 +772,6 @@ void NodeItem::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
     return QGraphicsItem::mouseMoveEvent(event);
 
   auto parent = this->parentItem();
-
   auto origp = parent->mapFromScene(event->buttonDownScenePos(Qt::LeftButton));
   auto p = parent->mapFromScene(event->scenePos());
   if(p != origp)
@@ -723,16 +783,17 @@ void NodeItem::mouseMoveEvent(QGraphicsSceneMouseEvent* event)
     {
       case Interaction::Resize: {
         const auto sz = origNodeSize + QSizeF{p.x() - origp.x(), p.y() - origp.y()};
-        m_context.dispatcher.submit<Process::ResizeNode>(
+        m_dispatcher.submit<Process::ResizeNode>(
             m_model, sz.expandedTo({minimalContentWidth(), minimalContentHeight()}));
         updateSize();
         break;
       }
       case Interaction::Move: {
-        m_context.dispatcher.submit<Process::MoveNodes>(
-            selectedProcesses(m_context), p - origp);
+        m_dispatcher.submit<Process::MoveNodes>(selectedProcesses(m_context), p - origp);
         break;
       }
+      default:
+        break;
     }
   }
   event->accept();
@@ -744,8 +805,9 @@ void NodeItem::mouseReleaseEvent(QGraphicsSceneMouseEvent* event)
     return QGraphicsItem::mouseReleaseEvent(event);
 
   mouseMoveEvent(event);
+
   if(nodeDidMove)
-    m_context.dispatcher.commit();
+    m_dispatcher.commit<Process::MoveNodesMacro>();
   nodeDidMove = false;
   event->accept();
 }
@@ -813,4 +875,32 @@ void NodeItem::keyReleaseEvent(QKeyEvent* event)
 {
   event->accept();
 }
+void NodeItem::dragEnterEvent(QGraphicsSceneDragDropEvent* event)
+{
+  m_dropping = true;
+  event->accept();
+  update();
+}
+
+void NodeItem::dragMoveEvent(QGraphicsSceneDragDropEvent* event)
+{
+  m_dropping = true;
+  event->accept();
+  update();
+}
+
+void NodeItem::dragLeaveEvent(QGraphicsSceneDragDropEvent* event)
+{
+  m_dropping = false;
+  event->accept();
+  update();
+}
+
+void NodeItem::dropEvent(QGraphicsSceneDragDropEvent* event)
+{
+  m_dropping = false;
+  event->accept();
+  dropReceived(event->pos(), *event->mimeData());
+  update();
+}
 }
