@@ -2,16 +2,18 @@
 #include <Process/ExecutionCommand.hpp>
 #include <Process/ExecutionContext.hpp>
 
-#include <memory>
+#include <ossia/detail/thread.hpp>
+
 #include <verdigris>
 
 namespace Execution
 {
 struct Context;
-template <typename T>
-inline constexpr auto gc(T&& t) noexcept
+template <typename... T>
+inline constexpr auto gc(T&&... t) noexcept
 {
-  return [gced = std::move(t)] {};
+  return
+      [... gced = std::move(t)] { OSSIA_ENSURE_CURRENT_THREAD(ossia::thread_type::Ui); };
 }
 
 struct Transaction
