@@ -146,9 +146,12 @@ void PipeWireAudioFactory::setupSettingsWidget(
     return;
   }
 
-  if(auto str = qgetenv("PIPEWIRE_LATENCY"); !str.isEmpty())
+  auto lat = qgetenv("PIPEWIRE_LATENCY");
+  if(lat.isEmpty())
+    lat = qgetenv("PIPEWIRE_QUANTUM");
+  if(!lat.isEmpty())
   {
-    if(auto ss = str.split('/'); ss.size() == 2)
+    if(auto ss = lat.split('/'); ss.size() == 2)
     {
       bool ok{};
       int buffer_size = ss[0].toInt(&ok);
@@ -164,6 +167,11 @@ void PipeWireAudioFactory::setupSettingsWidget(
     }
   }
 
+  lay->addRow(new QLabel{tr(
+      "To configure buffer size and sample rate with pipewire, set the PIPEWIRE_QUANTUM "
+      "environment variable before starting ossia:\n\n"
+      "    #Set buffer size to 256 and sample rate to 48000\n"
+      "    export PIPEWIRE_QUANTUM=256/48000\n")});
   /*
   {
     auto rate = jack_get_sample_rate(clt);
