@@ -3,11 +3,13 @@
 
 #include <score/command/AggregateCommand.hpp>
 
+#include <score_plugin_deviceexplorer_export.h>
 namespace Explorer
 {
 namespace Command
 {
-class RemoveNodes final : public score::AggregateCommand
+class SCORE_PLUGIN_DEVICEEXPLORER_EXPORT RemoveNodes final
+    : public score::AggregateCommand
 {
   SCORE_COMMAND_DECL(
       DeviceExplorerCommandFactoryName(), RemoveNodes, "Remove Explorer nodes")
