@@ -21,7 +21,7 @@ View::View()
   m_cb = new QCheckBox{tr("Enable local tree")};
   lay->addRow(m_cb);
 
-  connect(m_cb, &QCheckBox::stateChanged, this, [this](int b) { localTreeChanged(b); });
+  connect(m_cb, SignalUtils::QCheckBox_checkStateChanged(), this, [this](int b) { localTreeChanged(b); });
 }
 
 void View::setLocalTree(bool val)
