@@ -4,6 +4,8 @@
 #include <score/application/ApplicationContext.hpp>
 #include <score/gfx/Vulkan.hpp>
 
+#include <core/application/ApplicationInterface.hpp>
+
 #include <QGuiApplication>
 #include <QPlatformSurfaceEvent>
 #include <QTimer>
@@ -287,7 +289,8 @@ bool Window::event(QEvent* e)
         this->interactiveEvent(e);
         if(ev->key() == Qt::Key_Escape)
           if(m_embeddedFullscreen)
-            QMetaObject::invokeMethod(qGuiApp, &QCoreApplication::quit);
+            QMetaObject::invokeMethod(
+                qGuiApp, [] { score::GUIApplicationInterface::instance().forceExit(); });
       }
 
       break;
