@@ -23,6 +23,14 @@
 #include <Gfx/Text/Executor.hpp>
 #include <Gfx/Text/Process.hpp>
 #include <Gfx/TexturePort.hpp>
+#include <Gfx/VSA/Executor.hpp>
+#include <Gfx/VSA/Layer.hpp>
+#include <Gfx/VSA/Library.hpp>
+#include <Gfx/VSA/Process.hpp>
+#include <Gfx/CSF/Executor.hpp>
+#include <Gfx/CSF/Layer.hpp>
+#include <Gfx/CSF/Library.hpp>
+#include <Gfx/CSF/Process.hpp>
 #include <Gfx/Video/Executor.hpp>
 #include <Gfx/Video/Inspector.hpp>
 #include <Gfx/Video/Layer.hpp>
@@ -103,15 +111,19 @@ std::vector<score::InterfaceBase*> score_plugin_gfx::factories(
          >,
       FW<Process::ProcessModelFactory, Gfx::Filter::ProcessFactory,
          Gfx::GeometryFilter::ProcessFactory, Gfx::Video::ProcessFactory,
-         Gfx::Text::ProcessFactory, Gfx::Images::ProcessFactory>,
+         Gfx::Text::ProcessFactory, Gfx::Images::ProcessFactory,
+         Gfx::VSA::ProcessFactory, Gfx::CSF::ProcessFactory>,
       FW<Process::LayerFactory, Gfx::Filter::LayerFactory,
-         Gfx::GeometryFilter::LayerFactory, Gfx::Video::LayerFactory>,
+         Gfx::GeometryFilter::LayerFactory, Gfx::Video::LayerFactory,
+         Gfx::VSA::LayerFactory, Gfx::CSF::LayerFactory>,
       FW<Execution::ProcessComponentFactory,
          Gfx::Filter::ProcessExecutorComponentFactory,
          Gfx::GeometryFilter::ProcessExecutorComponentFactory,
          Gfx::Video::ProcessExecutorComponentFactory,
          Gfx::Text::ProcessExecutorComponentFactory,
-         Gfx::Images::ProcessExecutorComponentFactory>,
+         Gfx::Images::ProcessExecutorComponentFactory,
+         Gfx::VSA::ProcessExecutorComponentFactory,
+         Gfx::CSF::ProcessExecutorComponentFactory>,
       FW<Inspector::InspectorWidgetFactory, Gfx::Video::InspectorFactory>,
       FW<Process::PortFactory,
          Dataflow::WidgetInletFactory<
@@ -121,8 +133,9 @@ std::vector<score::InterfaceBase*> score_plugin_gfx::factories(
       FW<Process::ProcessDropHandler, Gfx::Filter::DropHandler, Gfx::Video::DropHandler,
          Gfx::Images::DropHandler>,
       FW<Library::LibraryInterface, Gfx::Filter::LibraryHandler,
-         Gfx::Video::LibraryHandler, Gfx::Images::LibraryHandler,
-         Gfx::GeometryFilter::LibraryHandler>,
+         Gfx::VSA::LibraryHandler, Gfx::Video::LibraryHandler,
+         Gfx::Images::LibraryHandler, Gfx::GeometryFilter::LibraryHandler,
+         Gfx::CSF::LibraryHandler>,
       FW<score::SettingsDelegateFactory, Gfx::Settings::Factory>>(ctx, key);
 }
 
