@@ -3,7 +3,7 @@
 
 #include <score/application/ApplicationContext.hpp>
 
-#include <QApplication>
+#include <QCoreApplication>
 #include <QDebug>
 #include <QDir>
 #include <QDirIterator>
@@ -69,7 +69,7 @@ static inline std::string locateSDK()
     return libPath.toStdString();
   }
 
-  auto appFolder = qApp->applicationDirPath();
+  auto appFolder = QCoreApplication::instance()->applicationDirPath();
 
 #if !SCORE_FHS_BUILD
 
@@ -122,6 +122,58 @@ static inline std::string locateSDK()
 #endif
 }
 
+struct located_sdk
+{
+  std::string path;
+  enum
+  {
+    none,     // Nothing was found
+    platform, // Building against /usr/include, useful for dev builds
+    official  // The SDK obtained from official score releases
+  } sdk_kind
+      = none;
+
+// Do we use the score source dir or the headers from the SDK
+#if !SCORE_FHS_BUILD
+  static constexpr bool deploying = true;
+#else
+  static constexpr bool deploying = false;
+#endif
+};
+
+inline located_sdk locateSDKWithFallback()
+{
+  located_sdk ret;
+  ret.path = locateSDK();
+  if(ret.path.empty())
+    ret.sdk_kind = located_sdk::none;
+  if(ret.path.starts_with("/usr") || ret.path.starts_with("/Applications"))
+    ret.sdk_kind = located_sdk::official;
+  else
+    ret.sdk_kind = located_sdk::platform;
+
+  {
+    QDir dir(QString::fromStdString(ret.path));
+    if(!dir.exists())
+      ret.sdk_kind = located_sdk::none;
+
+    if(!dir.cd("include") || !dir.cd("c++"))
+    {
+      qDebug() << "Unable to locate standard headers, fallback to /usr";
+      ret.path = "/usr";
+      dir.setPath("/usr");
+      if(!dir.cd("include") || !dir.cd("c++"))
+      {
+        qDebug() << "Unable to locate any standard headers, install C++ development "
+                    "toolchain";
+        throw std::runtime_error("Unable to compile");
+      }
+      ret.sdk_kind = located_sdk::platform;
+    }
+  }
+  return ret;
+}
+
 static inline void
 populateCompileOptions(std::vector<std::string>& args, CompilerOptions opts)
 {
@@ -149,7 +201,7 @@ populateCompileOptions(std::vector<std::string>& args, CompilerOptions opts)
     }
   }
 
-  args.push_back("-std=c++2b");
+  args.push_back("-std=c++23");
   args.push_back("-disable-free");
   args.push_back("-fdeprecated-macro");
   args.push_back("-fmath-errno");
@@ -211,7 +263,7 @@ populateCompileOptions(std::vector<std::string>& args, CompilerOptions opts)
 
   // // tls:
   args.push_back("-ftls-model=local-exec");
-  // args.push_back("-fno-emulated-tls");
+  args.push_back("-femulated-tls");
 
   // if fsanitize:
   args.push_back("-mrelax-all");
@@ -272,66 +324,221 @@ static inline void populateDefinitions(std::vector<std::string>& args)
   // needed because otherwise readerwriterqueue includes CoreFoundation.h ...
   args.push_back("-DMOODYCAMEL_MAYBE_ALIGN_TO_CACHELINE=");
 #endif
-  args.push_back("-DBOOST_MATH_DISABLE_FLOAT128=1");
-  args.push_back("-DBOOST_ASIO_DISABLE_CONCEPTS=1");
+#define XSTR(s) STR(s)
+#define STR(s) #s
+
+#if defined(BOOST_ASIO_ENABLE_BUFFER_DEBUGGING)
+  args.push_back("-DBOOST_ASIO_ENABLE_BUFFER_DEBUGGING");
+#endif
+#if defined(BOOST_ASIO_HAS_STD_INVOKE_RESULT)
+  args.push_back(
+      "-DBOOST_ASIO_HAS_STD_INVOKE_RESULT=" XSTR(BOOST_ASIO_HAS_STD_INVOKE_RESULT));
+#endif
+#if defined(BOOST_MATH_DISABLE_FLOAT128)
+  args.push_back("-DBOOST_MATH_DISABLE_FLOAT128=" XSTR(BOOST_MATH_DISABLE_FLOAT128));
+#endif
+#if defined(BOOST_MULTI_INDEX_ENABLE_INVARIANT_CHECKING)
   args.push_back("-DBOOST_MULTI_INDEX_ENABLE_INVARIANT_CHECKING");
+#endif
+#if defined(BOOST_MULTI_INDEX_ENABLE_SAFE_MODE)
   args.push_back("-DBOOST_MULTI_INDEX_ENABLE_SAFE_MODE");
+#endif
+#if defined(BOOST_NO_RTTI)
+  args.push_back("-DBOOST_NO_RTTI=" XSTR(BOOST_NO_RTTI));
+#endif
+#if defined(FMT_SHARED)
+  args.push_back("-DFMT_SHARED=" XSTR(FMT_SHARED));
+#endif
+#if defined(FMT_STATIC_THOUSANDS_SEPARATOR)
+  args.push_back(
+      "-DFMT_STATIC_THOUSANDS_SEPARATOR=" XSTR(FMT_STATIC_THOUSANDS_SEPARATOR));
+#endif
+#if defined(FMT_USE_FLOAT128)
+  args.push_back("-DFMT_USE_FLOAT128=" XSTR(FMT_USE_FLOAT128));
+#endif
+#if defined(FMT_USE_INT128)
+  args.push_back("-DFMT_USE_INT128=" XSTR(FMT_USE_INT128));
+#endif
+#if defined(FMT_USE_LONG_DOUBLE)
+  args.push_back("-DFMT_USE_LONG_DOUBLE=" XSTR(FMT_USE_LONG_DOUBLE));
+#endif
+#if defined(LIBREMIDI_ALSA)
+  args.push_back("-DLIBREMIDI_ALSA");
+#endif
+#if defined(LIBREMIDI_HAS_JACK_GET_VERSION)
+  args.push_back("-DLIBREMIDI_HAS_JACK_GET_VERSION");
+#endif
+#if defined(LIBREMIDI_HAS_UDEV)
+  args.push_back("-DLIBREMIDI_HAS_UDEV");
+#endif
+#if defined(LIBREMIDI_JACK)
+  args.push_back("-DLIBREMIDI_JACK");
+#endif
+#if defined(LIBREMIDI_KEYBOARD)
+  args.push_back("-DLIBREMIDI_KEYBOARD");
+#endif
+#if defined(LIBREMIDI_PIPEWIRE)
+  args.push_back("-DLIBREMIDI_PIPEWIRE");
+#endif
+#if defined(LIBREMIDI_PIPEWIRE_UMP)
+  args.push_back("-DLIBREMIDI_PIPEWIRE_UMP");
+#endif
+#if defined(LIBREMIDI_USE_BOOST)
+  args.push_back("-DLIBREMIDI_USE_BOOST");
+#endif
+#if defined(LIBREMIDI_WEAKJACK)
+  args.push_back("-DLIBREMIDI_WEAKJACK");
+#endif
+#if defined(QT_CORE_LIB)
   args.push_back("-DQT_CORE_LIB");
-  args.push_back("-DQT_DISABLE_DEPRECATED_BEFORE=0x050800");
+#endif
+#if defined(QT_DISABLE_DEPRECATED_BEFORE)
+  args.push_back("-DQT_DISABLE_DEPRECATED_BEFORE=" XSTR(QT_DISABLE_DEPRECATED_BEFORE));
+#endif
+#if defined(QT_GUI_LIB)
   args.push_back("-DQT_GUI_LIB");
+#endif
+#if defined(QT_NETWORK_LIB)
   args.push_back("-DQT_NETWORK_LIB");
+#endif
+#if defined(QT_NO_JAVA_STYLE_ITERATORS)
+  args.push_back("-DQT_NO_JAVA_STYLE_ITERATORS");
+#endif
+#if defined(QT_NO_KEYWORDS)
   args.push_back("-DQT_NO_KEYWORDS");
+#endif
+#if defined(QT_NO_LINKED_LIST)
+  args.push_back("-DQT_NO_LINKED_LIST");
+#endif
+#if defined(QT_NO_NARROWING_CONVERSIONS_IN_CONNECT)
+  args.push_back("-DQT_NO_NARROWING_CONVERSIONS_IN_CONNECT");
+#endif
+#if defined(QT_NO_USING_NAMESPACE)
+  args.push_back("-DQT_NO_USING_NAMESPACE");
+#endif
+#if defined(QT_OPENGL_LIB)
+  args.push_back("-DQT_OPENGL_LIB");
+#endif
+#if defined(QT_QMLINTEGRATION_LIB)
+  args.push_back("-DQT_QMLINTEGRATION_LIB");
+#endif
+#if defined(QT_QML_LIB)
   args.push_back("-DQT_QML_LIB");
-  args.push_back("-DQT_QUICK_LIB");
+#endif
+#if defined(QT_SERIALPORT_LIB)
   args.push_back("-DQT_SERIALPORT_LIB");
-  args.push_back("-DQT_STATICPLUGIN");
-  args.push_back("-DQT_SVG_LIB");
+#endif
+#if defined(QT_SHADERTOOLS_LIB)
+  args.push_back("-DQT_SHADERTOOLS_LIB");
+#endif
+#if defined(QT_STATEMACHINE_LIB)
+  args.push_back("-DQT_STATEMACHINE_LIB");
+#endif
+#if defined(QT_USE_QSTRINGBUILDER)
+  args.push_back("-DQT_USE_QSTRINGBUILDER");
+#endif
+#if defined(QT_WEBSOCKETS_LIB)
   args.push_back("-DQT_WEBSOCKETS_LIB");
+#endif
+#if defined(QT_WIDGETS_LIB)
   args.push_back("-DQT_WIDGETS_LIB");
-  args.push_back("-DQT_XML_LIB");
-  args.push_back("-DRAPIDJSON_HAS_STDSTRING=1");
-
-  // TLS apparently not yet well supported by lljit :
-  // - undefined references to ___emutls_add_address
-  // - MachO TLV relocations not yet supported
-#if __APPLE__
-  args.push_back("-DSPDLOG_NO_TLS=1");
-  args.push_back("-DMOODYCAMEL_NO_THREAD_LOCAL=1");
-
-  args.push_back("-D__thread=__do_not_use_thread_local__");
-  args.push_back("-Dthread_local=__do_not_use_thread_local__");
-  args.push_back("-D_Thread_local=__do_not_use_thread_local__");
+#endif
+#if defined(RAPIDJSON_HAS_STDSTRING)
+  args.push_back("-DRAPIDJSON_HAS_STDSTRING=" XSTR(RAPIDJSON_HAS_STDSTRING));
+#endif
+#if defined(SCORE_DEBUG)
+  args.push_back("-DSCORE_DEBUG");
+#endif
+#if defined(SCORE_LIB_BASE)
+  args.push_back("-DSCORE_LIB_BASE");
+#endif
+#if defined(SCORE_LIB_DEVICE)
+  args.push_back("-DSCORE_LIB_DEVICE");
+#endif
+#if defined(SCORE_LIB_INSPECTOR)
+  args.push_back("-DSCORE_LIB_INSPECTOR");
+#endif
+#if defined(SCORE_LIB_LOCALTREE)
+  args.push_back("-DSCORE_LIB_LOCALTREE");
+#endif
+#if defined(SCORE_LIB_PROCESS)
+  args.push_back("-DSCORE_LIB_PROCESS");
+#endif
+#if defined(SCORE_LIB_STATE)
+  args.push_back("-DSCORE_LIB_STATE");
+#endif
+#if defined(SCORE_PLUGIN_AUDIO)
+  args.push_back("-DSCORE_PLUGIN_AUDIO");
+#endif
+#if defined(SCORE_PLUGIN_AUTOMATION)
+  args.push_back("-DSCORE_PLUGIN_AUTOMATION");
+#endif
+#if defined(SCORE_PLUGIN_AVND)
+  args.push_back("-DSCORE_PLUGIN_AVND");
+#endif
+#if defined(SCORE_PLUGIN_CURVE)
+  args.push_back("-DSCORE_PLUGIN_CURVE");
+#endif
+#if defined(SCORE_PLUGIN_DATAFLOW)
+  args.push_back("-DSCORE_PLUGIN_DATAFLOW");
+#endif
+#if defined(SCORE_PLUGIN_DEVICEEXPLORER)
+  args.push_back("-DSCORE_PLUGIN_DEVICEEXPLORER");
+#endif
+#if defined(SCORE_PLUGIN_ENGINE)
+  args.push_back("-DSCORE_PLUGIN_ENGINE");
+#endif
+#if defined(SCORE_PLUGIN_GFX)
+  args.push_back("-DSCORE_PLUGIN_GFX");
+#endif
+#if defined(SCORE_PLUGIN_LIBRARY)
+  args.push_back("-DSCORE_PLUGIN_LIBRARY");
+#endif
+#if defined(SCORE_PLUGIN_MEDIA)
+  args.push_back("-DSCORE_PLUGIN_MEDIA");
+#endif
+#if defined(SCORE_PLUGIN_SCENARIO)
+  args.push_back("-DSCORE_PLUGIN_SCENARIO");
+#endif
+#if defined(SCORE_PLUGIN_TRANSPORT)
+  args.push_back("-DSCORE_PLUGIN_TRANSPORT");
+#endif
+#if defined(SERVUS_USE_AVAHI_CLIENT)
+  args.push_back("-DSERVUS_USE_AVAHI_CLIENT");
+#endif
+#if defined(SPDLOG_COMPILED_LIB)
+  args.push_back("-DSPDLOG_COMPILED_LIB=" XSTR(BOOST_MATH_DISABLE_FLOAT128));
+#endif
+#if defined(SPDLOG_DEBUG_ON)
+  args.push_back("-DSPDLOG_DEBUG_ON=" XSTR(BOOST_MATH_DISABLE_FLOAT128));
+#endif
+#if defined(SPDLOG_FMT_EXTERNAL)
+  args.push_back("-DSPDLOG_FMT_EXTERNAL=" XSTR(BOOST_MATH_DISABLE_FLOAT128));
+#endif
+#if defined(SPDLOG_NO_DATETIME)
+  args.push_back("-DSPDLOG_NO_DATETIME=" XSTR(BOOST_MATH_DISABLE_FLOAT128));
+#endif
+#if defined(SPDLOG_NO_NAME)
+  args.push_back("-DSPDLOG_NO_NAME=" XSTR(BOOST_MATH_DISABLE_FLOAT128));
+#endif
+#if defined(SPDLOG_NO_THREAD_ID)
+  args.push_back("-DSPDLOG_NO_THREAD_ID=" XSTR(BOOST_MATH_DISABLE_FLOAT128));
+#endif
+#if defined(SPDLOG_SHARED_LIB)
+  args.push_back("-DSPDLOG_SHARED_LIB=" XSTR(BOOST_MATH_DISABLE_FLOAT128));
+#endif
+#if defined(SPDLOG_TRACE_ON)
+  args.push_back("-DSPDLOG_TRACE_ON=" XSTR(BOOST_MATH_DISABLE_FLOAT128));
+#endif
+#if defined(TINYSPLINE_DOUBLE_PRECISION)
+  args.push_back("-DTINYSPLINE_DOUBLE_PRECISION");
 #endif
 
 #if defined(SCORE_DEBUG)
   args.push_back("-DSCORE_DEBUG");
 #endif
-  args.push_back("-DSCORE_LIB_BASE");
-  args.push_back("-DSCORE_LIB_DEVICE");
-  args.push_back("-DSCORE_LIB_INSPECTOR");
-  args.push_back("-DSCORE_LIB_LOCALTREE");
-  args.push_back("-DSCORE_LIB_PROCESS");
-  args.push_back("-DSCORE_LIB_STATE");
-  args.push_back("-DSCORE_PLUGIN_GFX");
-  args.push_back("-DSCORE_PLUGIN_REMOTECONTROL");
-  args.push_back("-DSCORE_PLUGIN_NODAL");
-  args.push_back("-DSCORE_PLUGIN_AUDIO");
-  args.push_back("-DSCORE_PLUGIN_AUTOMATION");
-  args.push_back("-DSCORE_PLUGIN_CURVE");
-  args.push_back("-DSCORE_PLUGIN_DATAFLOW");
-  args.push_back("-DSCORE_PLUGIN_DEVICEEXPLORER");
-  args.push_back("-DSCORE_PLUGIN_ENGINE");
-  args.push_back("-DSCORE_PLUGIN_LIBRARY");
-  args.push_back("-DSCORE_PLUGIN_MAPPING");
-  args.push_back("-DSCORE_PLUGIN_MEDIA");
-  args.push_back("-DSCORE_PLUGIN_PROTOCOLS");
-  args.push_back("-DSCORE_PLUGIN_SCENARIO");
-  args.push_back("-DSCORE_PLUGIN_MIDI");
-  args.push_back("-DSCORE_PLUGIN_PROTOCOLS");
-  args.push_back("-DSCORE_PLUGIN_RECORDING");
-  args.push_back("-DSCORE_PLUGIN_TRANSPORT");
+
   // args.push_back("-DSCORE_STATIC_PLUGINS");
-  args.push_back("-DTINYSPLINE_DOUBLE_PRECISION");
   args.push_back("-D_GNU_SOURCE=1");
   args.push_back("-D__STDC_CONSTANT_MACROS");
   args.push_back("-D__STDC_FORMAT_MACROS");
@@ -350,6 +557,7 @@ static inline auto getPotentialTriples()
   triples.push_back(LLVM_HOST_TRIPLE);
 #if defined(__x86_64__)
   triples.push_back("x86_64-pc-linux-gnu");
+  triples.push_back("x86_64-unknown-linux-gnu");
 #elif defined(__i686__)
   triples.push_back("i686-pc-linux-gnu");
 #elif defined(__i586__)
@@ -374,8 +582,10 @@ static inline auto getPotentialTriples()
 #elif defined(__aarch64__)
   triples.push_back("aarch64-none-linux-gnueabi");
   triples.push_back("aarch64-pc-linux-gnueabi");
+  triples.push_back("aarch64-unknown-linux-gnueabi");
   triples.push_back("aarch64-none-linux-gnu");
   triples.push_back("aarch64-pc-linux-gnu");
+  triples.push_back("aarch64-unknown-linux-gnu");
   triples.push_back("aarch64-redhat-linux");
 #endif
 
@@ -422,29 +632,9 @@ static inline auto getPotentialTriples()
  */
 static inline void populateIncludeDirs(std::vector<std::string>& args)
 {
-  auto sdk = locateSDK();
+  auto sdk_location = locateSDKWithFallback();
+  auto& sdk = sdk_location.path;
   auto qsdk = QString::fromStdString(sdk);
-  std::cerr << "\nLooking for sdk in: " << sdk << "\n";
-  qDebug() << "Looking for sdk in: " << qsdk;
-
-  bool sdk_found = true;
-
-  {
-    QDir dir(qsdk);
-    if(!dir.cd("include") || !dir.cd("c++"))
-    {
-      qDebug() << "Unable to locate standard headers, fallback to /usr";
-      qsdk = "/usr";
-      sdk = "/usr";
-      dir.setPath("/usr");
-      if(!dir.cd("include") || !dir.cd("c++"))
-      {
-        qDebug() << "Unable to locate standard headers++";
-        throw std::runtime_error("Unable to compile");
-      }
-      sdk_found = false;
-    }
-  }
 
   qDebug() << "SDK located: " << qsdk;
   std::string llvm_lib_version = SCORE_LLVM_VERSION;
@@ -541,15 +731,34 @@ static inline void populateIncludeDirs(std::vector<std::string>& args)
   ///build/score.AppDir/usr/include/
 
   auto include = [&](const std::string& path) {
-    args.push_back("-I" + sdk + "/include/" + path);
+    std::string path_to_include = sdk + "/include/" + path;
+    auto qpath = QString::fromStdString(path_to_include);
+    if(!QFileInfo{qpath}.isDir())
+    {
+      qDebug() << "Trying to include non-existent path: " << qpath;
+    }
+    else
+    {
+      args.push_back("-isystem" + sdk + "/include/" + path);
+    }
   };
 
 #if defined(__linux__)
-  include("x86_64-linux-gnu"); // #debian
+// #debian
+#if defined(__x86_64__)
+  include("x86_64-linux-gnu");
+#else
+  include("aarch64-linux-gnu");
 #endif
+#endif
+
   // include(""); // /usr/include
+  std::string qt_folder = "qt";
+  if(QFile::exists(qsdk + "/include/qt6/QtCore"))
+    qt_folder = "qt6";
+
   QDirIterator qtVersionFolder{
-      qsdk + "/include/qt/QtCore",
+      qsdk + "/include/" + QString::fromStdString(qt_folder) + "/QtCore",
       {},
       QDir::Filter::Dirs | QDir::Filter::NoDotAndDotDot,
       {}};
@@ -559,64 +768,67 @@ static inline void populateIncludeDirs(std::vector<std::string>& args)
     QDir sub = qtVersionFolder.next();
     qt_version = sub.dirName().toStdString();
   }
-  include("qt");
-  include("qt/QtCore");
-  include("qt/QtCore/" + qt_version);
-  include("qt/QtCore/" + qt_version + "/QtCore");
-  include("qt/QtGui");
-  include("qt/QtGui/" + qt_version);
-  include("qt/QtGui/" + qt_version + "/QtGui");
-  include("qt/QtWidgets");
-  include("qt/QtWidgets/" + qt_version);
-  include("qt/QtWidgets/" + qt_version + "/QtWidgets");
-  include("qt/QtQml");
-  include("qt/QtQml/" + qt_version);
-  include("qt/QtQml/" + qt_version + "/QtQml");
-  include("qt/QtXml");
-  include("qt/QtNetwork");
-  include("qt/QtSvg");
-  include("qt/QtSql");
-  include("qt/QtOpenGL");
-  include("qt/QtShaderTools");
-  include("qt/QtShaderTools/" + qt_version);
-  include("qt/QtShaderTools/" + qt_version + "/QtShaderTools");
-  include("qt/QtSerialBus");
-  include("qt/QtSerialPort");
+  include(qt_folder + "");
+  include(qt_folder + "/QtCore");
+  include(qt_folder + "/QtCore/" + qt_version);
+  include(qt_folder + "/QtCore/" + qt_version + "/QtCore");
+  include(qt_folder + "/QtGui");
+  include(qt_folder + "/QtGui/" + qt_version);
+  include(qt_folder + "/QtGui/" + qt_version + "/QtGui");
+  include(qt_folder + "/QtWidgets");
+  include(qt_folder + "/QtWidgets/" + qt_version);
+  include(qt_folder + "/QtWidgets/" + qt_version + "/QtWidgets");
+  include(qt_folder + "/QtQml");
+  include(qt_folder + "/QtQml/" + qt_version);
+  include(qt_folder + "/QtQml/" + qt_version + "/QtQml");
+  include(qt_folder + "/QtQuick");
+  include(qt_folder + "/QtQuick/" + qt_version);
+  include(qt_folder + "/QtQuick/" + qt_version + "/QtQuick");
+  include(qt_folder + "/QtXml");
+  include(qt_folder + "/QtNetwork");
+  include(qt_folder + "/QtSvg");
+  include(qt_folder + "/QtSql");
+  include(qt_folder + "/QtOpenGL");
+  include(qt_folder + "/QtShaderTools");
+  include(qt_folder + "/QtShaderTools/" + qt_version);
+  include(qt_folder + "/QtShaderTools/" + qt_version + "/QtShaderTools");
+  include(qt_folder + "/QtSerialPort");
 
-#if !SCORE_FHS_BUILD
-  bool deploying = true;
-#else
-  bool deploying = false;
-#endif
-
-  if(deploying && sdk_found)
+  if(sdk_location.sdk_kind == located_sdk::official && sdk_location.deploying)
   {
     include("score");
   }
   else
   {
+    auto thirdparty_include_dirs = {
+        "/3rdparty/libossia/3rdparty/boost_1_88_0",
+        "/3rdparty/libossia/3rdparty/nano-signal-slot/include",
+        "/3rdparty/libossia/3rdparty/spdlog/include",
+        "/3rdparty/libossia/3rdparty/dr_libs",
+        "/3rdparty/libossia/3rdparty/Flicks",
+        "/3rdparty/libossia/3rdparty/fmt/include",
+        "/3rdparty/libossia/3rdparty/magic_enum/include",
+        "/3rdparty/libossia/3rdparty/readerwriterqueue",
+        "/3rdparty/libossia/3rdparty/concurrentqueue",
+        "/3rdparty/libossia/3rdparty/SmallFunction/smallfun/include",
+        "/3rdparty/libossia/3rdparty/websocketpp",
+        "/3rdparty/libossia/3rdparty/rapidjson/include",
+        "/3rdparty/libossia/3rdparty/libremidi/include",
+        "/3rdparty/libossia/3rdparty/oscpack",
+        "/3rdparty/libossia/3rdparty/rnd/include",
+        "/3rdparty/libossia/3rdparty/span/include",
+        "/3rdparty/libossia/3rdparty/tuplet/include",
+        "/3rdparty/libossia/3rdparty/unordered_dense/include",
+        "/3rdparty/libossia/3rdparty/multi_index/include",
+        "/3rdparty/libossia/3rdparty/verdigris/src",
+        "/3rdparty/libossia/3rdparty/weakjack",
+    };
+    for(auto path : thirdparty_include_dirs)
+    {
+      args.push_back("-isystem" + std::string(SCORE_ROOT_SOURCE_DIR) + path);
+    }
     auto src_include_dirs
         = {"/3rdparty/libossia/src",
-           "/3rdparty/libossia/3rdparty/boost_1_82_0",
-           "/3rdparty/libossia/3rdparty/nano-signal-slot/include",
-           "/3rdparty/libossia/3rdparty/spdlog/include",
-           "/3rdparty/libossia/3rdparty/brigand/include",
-           "/3rdparty/libossia/3rdparty/Flicks",
-           "/3rdparty/libossia/3rdparty/fmt/include",
-           "/3rdparty/libossia/3rdparty/readerwriterqueue",
-           "/3rdparty/libossia/3rdparty/concurrentqueue",
-           "/3rdparty/libossia/3rdparty/SmallFunction/smallfun/include",
-           "/3rdparty/libossia/3rdparty/websocketpp",
-           "/3rdparty/libossia/3rdparty/rapidjson/include",
-           "/3rdparty/libossia/3rdparty/libremidi/include",
-           "/3rdparty/libossia/3rdparty/oscpack",
-           "/3rdparty/libossia/3rdparty/rnd/include",
-           "/3rdparty/libossia/3rdparty/span/include",
-           "/3rdparty/libossia/3rdparty/tuplet/include",
-           "/3rdparty/libossia/3rdparty/unordered_dense/include",
-           "/3rdparty/libossia/3rdparty/multi_index/include",
-           "/3rdparty/libossia/3rdparty/verdigris/src",
-           "/3rdparty/libossia/3rdparty/weakjack",
            "/3rdparty/avendish/include",
            "/src/lib",
            "/src/plugins/score-lib-state",
