@@ -1,5 +1,7 @@
 #include <JS/Qml/Utils.hpp>
 
+#include <score/application/GUIApplicationContext.hpp>
+#include <score/tools/File.hpp>
 #include <score/tools/ThreadPool.hpp>
 
 #include <ossia/detail/algorithms.hpp>
@@ -17,12 +19,25 @@ namespace JS
 
 QByteArray JsUtils::readFile(QString path)
 {
+  if(auto doc = score::AppContext().currentDocument())
+    path = score::locateFilePath(path, *doc);
+
   QFile f(path);
   if(f.open(QIODevice::ReadOnly))
     return f.readAll();
   return {};
 }
 
+void JsUtils::writeFile(QString path, QByteArray content)
+{
+  if(auto doc = score::AppContext().currentDocument())
+    path = score::locateFilePath(path, *doc);
+
+  QFile f(path);
+  if(f.open(QIODevice::WriteOnly))
+    f.write(content);
+}
+
 void JsUtils::shell(QString cmd, QJSValue onFinish)
 {
 #if QT_CONFIG(process)
