@@ -18,4 +18,5 @@ PROCESS_METADATA(
     {std::vector<Process::PortType>{Process::PortType::Message}},
     {std::vector<Process::PortType>{Process::PortType::Message}},
     QUrl("https://ossia.io/score-docs/processes/2Dspline.html#generating-a-curve"),
-    Process::ProcessFlags::SupportsLasting)
+    Process::ProcessFlags::SupportsLasting
+        | Process::ProcessFlags::ItemRequiresUniqueFocus)
