@@ -6,6 +6,7 @@
 #include <score/tools/File.hpp>
 #include <score/tools/FindStringInFile.hpp>
 
+#include <QDirIterator>
 #include <QFile>
 #include <QFileInfo>
 #include <QTimer>
@@ -50,4 +51,41 @@ void LibraryDeviceEnumerator::enumerate(
 {
 }
 
+SubfolderDeviceEnumerator::SubfolderDeviceEnumerator(
+    QStringList roots, Device::ProtocolFactory::ConcreteKey k, func_type createDev,
+    const score::DocumentContext& ctx)
+    : m_key{k}
+    , m_createDeviceSettings{createDev}
+{
+  for(const auto& root : roots)
+  {
+    QTimer::singleShot(10, this, [this, root, n = roots.size()] {
+      QDirIterator it{
+          root, QDir::Dirs | QDir::NoDotAndDotDot, QDirIterator::NoIteratorFlags};
+      while(it.hasNext())
+      {
+        for(auto spec : m_createDeviceSettings(it.next()))
+        {
+          Device::DeviceSettings s;
+          s.name = spec.first;
+          s.protocol = m_key;
+          s.deviceSpecificSettings = std::move(spec.second);
+          deviceAdded(s.name, s);
+        }
+      }
+
+      m_finished++;
+      if(m_finished == n)
+        this->sort();
+    });
+  }
+}
+
+void SubfolderDeviceEnumerator::next(std::string_view path) { }
+
+void SubfolderDeviceEnumerator::enumerate(
+    std::function<void(const QString&, const Device::DeviceSettings&)> onDevice) const
+{
+}
+
 }
