@@ -26,6 +26,7 @@
 
 #include <ossia-qt/invoke.hpp>
 
+#include <QGuiApplication>
 #include <QInputDialog>
 #include <QTimer>
 
@@ -154,7 +155,7 @@ QString Model::prettyName() const noexcept
 bool Model::hasExternalUI() const noexcept
 {
 #if defined(__linux__)
-  static const thread_local bool is_wayland = qApp->platformName() == "wayland";
+  static const thread_local bool is_wayland = qGuiApp->platformName() == "wayland";
   if(is_wayland)
     return false;
 #endif
@@ -221,6 +222,7 @@ void Model::removeControl(const Id<Process::Port>& id)
   m_inlets.erase(it);
 
   controlRemoved(*ctrl);
+  // FIXME inletsChanged
   delete ctrl;
 }
 
@@ -245,6 +247,7 @@ void Model::on_addControl_impl(
   m_inlets.push_back(ctrl);
   initControl(ctrl, info);
   controlAdded(ctrl->id());
+  // FIXME inletsChanged
 }
 
 void Model::initControl(ControlInlet* ctrl, const Steinberg::Vst::ParameterInfo* info)
