@@ -6,6 +6,7 @@
 #include <Control/DefaultEffectItem.hpp>
 #include <Effect/EffectFactory.hpp>
 #include <Vst3/Plugin.hpp>
+#include <Vst3/UI/WindowContainer.hpp>
 
 #include <score/tools/std/Invoke.hpp>
 
@@ -36,7 +37,8 @@ namespace vst3
 class CreateVSTControl;
 class ControlInlet;
 struct PortCreationVisitor;
-
+class PlugFrame;
+class Window;
 class Model final : public Process::ProcessModel
 {
   W_OBJECT(Model)
@@ -71,8 +73,8 @@ public:
 
   void addControlFromEditor(Steinberg::Vst::ParamID id);
   void on_addControl(const Steinberg::Vst::ParameterInfo& v);
-  void on_addControl_impl(ControlInlet* inl);
-  void initControl(ControlInlet* inl);
+  void on_addControl_impl(ControlInlet* inl, const Steinberg::Vst::ParameterInfo*);
+  void initControl(ControlInlet* inl, const Steinberg::Vst::ParameterInfo*);
 
   void reloadControls();
   Steinberg::tresult restartComponent(int32_t flags);
