@@ -7,13 +7,14 @@
 
 namespace vst3
 {
-Window::Window(const Model& e, const score::DocumentContext& ctx, QWidget* parent)
+Window::Window(Model& e, const score::DocumentContext& ctx, QWidget* parent)
     : PluginWindow{ctx.app.settings<Media::Settings::Model>().getVstAlwaysOnTop(), parent}
     , m_model{e}
 {
   if(!e.fx)
     throw std::runtime_error("Cannot create UI");
 
+  e.fx.loadView(e);
   container = createVstWindowContainer(*this, e, ctx);
   show();
 
@@ -23,9 +24,15 @@ Window::Window(const Model& e, const score::DocumentContext& ctx, QWidget* paren
 Window::~Window()
 {
   if(m_model.fx.view)
-  {
     m_model.fx.view->setFrame(nullptr);
-    m_model.fx.view->removed();
+
+  if(auto view = m_model.fx.view)
+  {
+    view->removed();
+    if(m_model.fx.ui_owned)
+      view->release();
+
+    const_cast<Plugin&>(m_model.fx).view = nullptr;
   }
 
   if(container.frame)
@@ -44,9 +51,18 @@ void Window::resizeEvent(QResizeEvent* event)
 void Window::closeEvent(QCloseEvent* event)
 {
   QPointer<Window> p(this);
-  m_model.fx.view->setFrame(nullptr);
+
+  if(m_model.fx.view)
+    m_model.fx.view->setFrame(nullptr);
+
   if(auto view = m_model.fx.view)
+  {
     view->removed();
+    if(m_model.fx.ui_owned)
+      view->release();
+
+    const_cast<Plugin&>(m_model.fx).view = nullptr;
+  }
   container.frame = nullptr;
 
   const_cast<QWidget*&>(m_model.externalUI) = nullptr;
